/**
 * Copyright (C) 2016  Dušan Vejnovič  <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dtabs.demo.tabs.types;

import java.util.Arrays;
import java.util.List;

import org.dussan.vaadin.dtabs.demo.api.TabType;

public enum BottomTabTypes
        implements TabType
{

    // definition: tab type, tabs, is new
    DEFAULT( "bottomTabs", "Tab bar on bottom", "Tab bar on bottom", true ), //
    BASIC( "basic", "Basic tabs", "Basic tabs", true ), //
    CENTERED_TABS( "centeredTabs", "Centered tabs", "Centered tabs", true ), //
    COMPACTED_TABBAR( "compactedTabbar", "Compacted tab bar", "Compacted tab bar", true ), //
    EQUAL_WIDTH_TABS( "equalWidthTabs", "Equal width tabs", "Equal width tabs", true ), //
    ICONS_ON_TOP( "iconsOnTop", "Icons on top", "Icons on top", true ), //
    ONLY_SELECTED_TAB_IS_CLOSABLE( "onlySelectedTabIsClosable", "Only selected tab is closable",
        "Only selected tab is closable", true ), //
    PADDED_TABBAR( "paddedTabbar", "Padded tab bar", "Padded tab bar", true ), //
    RIGHT_ALIGNED_TABS( "rightAlignedTabs", "Right aligned tabs", "Right aligned tabs", true ), //
    TABS_WITH_PROPERTIES( "tabsWithProperties", "Tabs with properties", "Tabs with properties", true ), //
    UNFRAMED_TABS( "unframedTabs", "Unframed tabs", "Unframed tabs", true );

    private final transient List<Object> tab;

    private BottomTabTypes( Object... tabs )
    {
        this.tab = Arrays.asList( tabs );
    }

    private List<Object> getValues()
    {
        return tab;
    }

    public static BottomTabTypes fromString( String tab )
    {
        if ( tab != null )
        {
            for ( BottomTabTypes tempTab : BottomTabTypes.values() )
            {
                if ( tempTab.getValues()
                            .contains( tab ) )
                {
                    return tempTab;
                }
            }
        }
        return DEFAULT;
    }

    @Override
    public String getPath()
    {
        return tab.get( 0 )
                  .toString();
    }

    @Override
    public String getDescription()
    {
        return tab.get( 1 )
                  .toString();
    }

    @Override
    public String getLongDescription()
    {
        return tab.get( 2 )
                  .toString();
    }

    @Override
    public boolean isNew()
    {
        return Boolean.parseBoolean( tab.get( 3 )
                                        .toString() );
    }

    @Override
    public String toString()
    {
        return getPath();
    }

}
